==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/formats/microdvd/microdvdoutputformat.h <==
#ifndef MICRODVDOUTPUTFORMAT_H
#define MICRODVDOUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <outputformat.h>
#include <subtitleiterator.h>

#include <qstring.h>

namespace SubtitleComposer
{
	class MicroDVDOutputFormat : public OutputFormat
	{
		friend class FormatsManager;

		public:

			~MicroDVDOutputFormat() {}

			virtual QString dumpSubtitles( const Subtitle& subtitle, bool primary ) const
			{
				QString ret;

				double framesPerSecond = subtitle.framesPerSecond();
				ret += m_lineBuilder.arg( 1 ).arg( 1 ).arg( "" ).arg( QString::number( framesPerSecond, 'f', 3 ) );

				for ( SubtitleIterator it( subtitle ); it.current(); ++it )
				{
					const SubtitleLine* line = it.current();

					ret += m_lineBuilder
						.arg( (long)((line->showTime().toMillis()/1000.0)*framesPerSecond + 0.5) )
						.arg( (long)((line->hideTime().toMillis()/1000.0)*framesPerSecond + 0.5) )
						.arg( m_map[line->styleFlags()] )
						.arg( (primary ? line->primaryText() : line->secondaryText()).replace( "\n", "|" ) );
				}

				return ret;
			}

		protected:

			MicroDVDOutputFormat():
				OutputFormat( "MicroDVD", QStringList::split( ":", "sub:txt" ) ),
				m_lineBuilder( "{%1}{%2}%3%4\n" ),
				m_map()
			{
				m_map[0] = "";
				m_map[SubtitleLine::Bold] = "{Y:b}";
				m_map[SubtitleLine::Italic] = "{Y:i}";
				m_map[SubtitleLine::Underline] = "{Y:u}";
				m_map[SubtitleLine::Bold|SubtitleLine::Italic] = "{Y:bi}";
				m_map[SubtitleLine::Bold|SubtitleLine::Underline] = "{Y:ub}";
				m_map[SubtitleLine::Italic|SubtitleLine::Underline] = "{Y:ui}";
				m_map[SubtitleLine::Bold|SubtitleLine::Italic|SubtitleLine::Underline] = "{Y:ubi}";
			}

			const QString m_lineBuilder;
			QMap<int,QString> m_map;
	};
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/formats/microdvd/microdvdoutputformat.h <==
#ifndef MICRODVDOUTPUTFORMAT_H
#define MICRODVDOUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <outputformat.h>
#include <subtitleiterator.h>

namespace SubtitleComposer
{
	class MicroDVDOutputFormat : public OutputFormat
	{
		friend class FormatManager;

		public:

			~MicroDVDOutputFormat() {}

			virtual QString dumpSubtitles( const Subtitle& subtitle, bool primary ) const
			{
				QString ret;

				double framesPerSecond = subtitle.framesPerSecond();
				ret += m_lineBuilder.arg( 1 ).arg( 1 ).arg( "" ).arg( QString::number( framesPerSecond, 'f', 3 ) );

				for ( SubtitleIterator it( subtitle ); it.current(); ++it )
				{
					const SubtitleLine* line = it.current();

					const SString& text = primary ? line->primaryText() : line->secondaryText();

					ret += m_lineBuilder
						.arg( (long)((line->showTime().toMillis()/1000.0)*framesPerSecond + 0.5) )
						.arg( (long)((line->hideTime().toMillis()/1000.0)*framesPerSecond + 0.5) )
						.arg( m_map[text.cumStyleFlags()] )
						.arg( text.string().replace( "\n", "|" ) );
				}

				return ret;
			}

		protected:

			MicroDVDOutputFormat():
				OutputFormat( "MicroDVD", QStringList::split( ":", "sub:txt" ) ),
				m_lineBuilder( "{%1}{%2}%3%4\n" ),
				m_map()
			{
				m_map[0] = "";
				m_map[SString::Bold] = "{Y:b}";
				m_map[SString::Italic] = "{Y:i}";
				m_map[SString::Underline] = "{Y:u}";
				m_map[SString::Bold|SString::Italic] = "{Y:bi}";
				m_map[SString::Bold|SString::Underline] = "{Y:ub}";
				m_map[SString::Italic|SString::Underline] = "{Y:ui}";
				m_map[SString::Bold|SString::Italic|SString::Underline] = "{Y:ubi}";
			}

			const QString m_lineBuilder;
			QMap<int,QString> m_map;
	};
}

#endif
